{% extends "admin/base.html" %}
{% load i18n %}
 
{% block title %}{{ title }} | {% trans 'Site Utils Admin' %}{% endblock %}

{% block extrastyle %}
<style>
#header {
  background-color: #144153;
  border-bottom: solid 3px #fab732;
  color: #a9c4eb;
}
 
#branding h1 {
  color: #fff;
}

.module h2,
#content-related .module h2,
.module caption,
.inline-group h2 {
  background: #144153 !important;
  color: #ffe !important;
}

.selector h2 {
  border-color: #c3f0fa !important;
}

div.module {
  border-color: #afafbf;
}

a,
a:link,
a:visited,
#changelist-filter a:hover {
  color: #fab732;
}

a:hover {
  color: #ffaa00;
  text-decoration: underline;
}

#changelist-filter li.selected a {
  color: #144153 !important;
}

a.section
a.section:link,
a.section:visited {
  color: #ffe;
}

a.section:hover {
  color: #fff;
  text-decoration: underline;
}

tr.row1 {
  background-color: #eee;
}

.button.default,
input[type="submit"].default,
.submit-row input.default {
  background: #144153;
  border: 1px solid #0a2631;
}

ul.messagelist li {
  background-color: #eff;
}
</style>
{% endblock %}

{% block branding %}
<h1 id="site-name">{% trans 'Site Utils Admin' %}</h1>
{% endblock %}
 
{% block nav-global %}{% endblock %}